PCB Environment: Length< T, M1, Q1 > Class Template Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
Length< T, M1, Q1 > Class Template Reference

## Public Member Functions
| Length (int32_t i)
| Length (int64_t i)
| Length (T v)
template<double M2, double Q2>
| Length (const Length< T, M2, Q2 > &l)
T | value () const
Length< T, M1, Q1 > | operator+ (const Length< T, M1, Q1 > &l) const
Length< T, M1, Q1 > | operator- (const Length< T, M1, Q1 > &l) const
Length< T, M1, Q1 > & | operator+= (const Length< T, M1, Q1 > &l)
Length< T, M1, Q1 > & | operator-= (const Length< T, M1, Q1 > &l)
Length< T, M1, Q1 > | operator* (T s) const
Length< T, M1, Q1 > & | operator*= (T s)
template<double M2, double Q2>
bool | operator< (const Length< T, M2, Q2 > &l) const
template<double M2, double Q2>
bool | operator<= (const Length< T, M2, Q2 > &l) const
template<double M2, double Q2>
bool | operator== (const Length< T, M2, Q2 > &l) const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Units.hpp